.. _spkg_anyio:

anyio: High level compatibility layer for multiple asynchronous event loop implementations
====================================================================================================

Description
-----------

High level compatibility layer for multiple asynchronous event loop implementations

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/anyio/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_exceptiongroup`
- :ref:`spkg_idna`
- :ref:`spkg_pip`
- :ref:`spkg_sniffio`
- :ref:`spkg_typing_extensions`

Version Information
-------------------

package-version.txt::

    4.4.0

version_requirements.txt::

    anyio


Equivalent System Packages
--------------------------

(none known)

